package #
  Path::Extended::Test::File;

use strict;
use warnings;
use base qw( Path::Extended::File );

1;
